Skip to contents

fitted returns the fitted frontier values from stochastic metafrontier models estimated with sfametafrontier.

Usage

# S3 method for class 'sfametafrontier'
fitted(object, ...)

Arguments

object

A stochastic metafrontier model returned by sfametafrontier.

...

Currently ignored.

Value

A vector of fitted values is returned.

Note

The fitted values are ordered in the same way as the corresponding observations in the dataset used for the estimation.

See also

sfametafrontier, for the stochastic metafrontier analysis model fitting function using cross-sectional or pooled data.